SystemOrganization addCategory: #'GT-EventRecorder-Tests'!

TestCase subclass: #GTEventPackingTest
	instanceVariableNames: 'packing'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests'!

!GTEventPackingTest commentStamp: '<historical>' prior: 0!
A GTEventPackingTest is a test class for testing the behavior of GTEventPacking!

!GTEventPackingTest class methodsFor: 'testing' stamp: 'JurajKubelka 10/10/2015 15:22'!
isAbstract
	^ self name = GTEventPackingTest name! !

!GTEventPackingTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 15:23'!
packingClass
	^ self subclassResponsibility! !

!GTEventPackingTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 15:23'!
setUp
	super setUp.
	packing := self packingClass new.! !

!GTEventPackingTest methodsFor: 'tests-packing' stamp: 'JurajKubelka 10/9/2015 15:30'!
testAnnouncementWith
	| data announcement |
	data := #[1 2 3 4].
	announcement := packing announcementWith: data.
	self assert: announcement data equals: data.! !

!GTEventPackingTest methodsFor: 'tests-packing' stamp: 'JurajKubelka 10/9/2015 16:22'!
testPack
	| event1 event2 bundle  announcement collector unpackedData |
	event1 := GTDummyEvent new data: 'string'.
	event2 := GTDummyEvent new data: 42.
	collector := GTEventCollector new.
	collector add: event1; add: event2.
	bundle := packing pack: collector.
	self assert: bundle url equals: collector url.
	self assert: bundle data isLiteral.
	announcement := packing unpack: bundle data.
	unpackedData := announcement unpackedData.
	self assert: unpackedData size equals: 2.
	self assert: unpackedData first equals: event1.
	self assert: unpackedData second equals: event2.
! !

GTEventPackingTest subclass: #GTFuelPackingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests'!

!GTFuelPackingTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 15:23'!
packingClass
	^ GTFuelPacking! !

GTEventPackingTest subclass: #GTStonPackingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests'!

!GTStonPackingTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 15:24'!
packingClass
	^ GTStonPacking! !

TestCase subclass: #GTEventRecorderTest
	instanceVariableNames: 'recorder server collector url event1 event2 delegate receivedContents semaphore receiverSemaphore'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests'!

!GTEventRecorderTest methodsFor: 'asserting' stamp: 'JurajKubelka 10/9/2015 21:37'!
assertReceiverSemaphore
	self deny: (receiverSemaphore waitTimeoutMSecs: 200)! !

!GTEventRecorderTest methodsFor: 'asserting' stamp: 'JurajKubelka 10/9/2015 21:30'!
assertSemaphore
	self deny: (semaphore waitTimeoutMSecs: 200)! !

!GTEventRecorderTest methodsFor: 'server handling' stamp: 'JurajKubelka 10/9/2015 21:37'!
handleRequest: request response: response
	receivedContents nextPut: request contents.
	receiverSemaphore signal.
	^ response! !

!GTEventRecorderTest methodsFor: 'running' stamp: 'JurajKubelka 10/9/2015 21:26'!
setUp
	super setUp.
	self setUpServer.
	semaphore := Semaphore new.
	recorder := GTEventRecorder new.
	recorder offerPrivacy.
	collector := GTEventCollector new.
	collector url: url.
	event1 := GTDummyEvent new data: 'string1'.
	event2 := GTDummyEvent new data: 42! !

!GTEventRecorderTest methodsFor: 'running' stamp: 'JurajKubelka 10/9/2015 21:37'!
setUpServer
	receivedContents := WaitfreeQueue new.
	receiverSemaphore := Semaphore new.
	delegate := ZnDispatcherDelegate new.
	delegate
		map: '/'
		to:
			[ :request :response | self handleRequest: request response: response ].
	server := ZnServer on: 0.
	server delegate: delegate.
	server start.
	url := ZnUrl new
		scheme: #http;
		host: NetNameResolver loopBackName;
		port: server serverSocket port! !

!GTEventRecorderTest methodsFor: 'running' stamp: 'JurajKubelka 10/9/2015 11:53'!
tearDown
	super tearDown.
	recorder deactivateDelivery.
	server stop.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 10/9/2015 10:29'!
testAddCollector
	recorder addCollector: GTEventCollector new.
	self assert: recorder numberOfCollectors equals: 1.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 10/9/2015 11:53'!
testAddCollector2
	recorder addCollector: GTEventCollector new.
	self assert: recorder isDeliveryActive.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 10/9/2015 21:37'!
testAddCollector3
	recorder addCollector: collector.
	collector add: event1.
	collector add: event2.
	recorder announcer 
		when: GTEventSuspendingDeliveryAnnouncement
		do: [ semaphore signal ].
	self assertSemaphore.
	recorder deliverNow.
	self assertReceiverSemaphore.
	self assert: collector size equals: 0.
	! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 10/9/2015 17:13'!
testAddCollector4
	recorder addCollector: collector.
	collector add: event1.
	collector add: event2.
	recorder delivery packAndDeliver: false.
	"wait"
	self assert: collector size equals: 0.
	! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 10/9/2015 11:56'!
testDeliverNow
	"Just test that we can ask for delivering."
	recorder deliverNow! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 10/9/2015 10:40'!
testIsDeliveryActive
	self deny: recorder isDeliveryActive.! !

!GTEventRecorderTest methodsFor: 'tests' stamp: 'JurajKubelka 10/9/2015 15:46'!
testPack
	recorder addCollector: collector.
	collector add: event1.
	collector add: event2.
	recorder pack.
	self assert: collector size equals: 0.
	self assert: recorder delivery size equals: 1.! !

TestCase subclass: #GlobalIdentifierMergerTest
	instanceVariableNames: 'existing stored merger'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests'!

!GlobalIdentifierMergerTest commentStamp: '<historical>' prior: 0!
A GlobalIdentifierMergerTest is a test class for testing the behavior of GlobalIdentifierMerger!

!GlobalIdentifierMergerTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 19:44'!
setUp
	super setUp.
	existing := Dictionary new.
	stored := Dictionary new.
	merger := GlobalIdentifierMerger new.
	merger existing: existing; stored: stored! !

!GlobalIdentifierMergerTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 20:07'!
testMerge
	"Existing is empty. Stored has value."
	stored at: #a put: 42.
	self assert: merger merge.
	self assert: existing equals: stored.
	self assert: (existing at: #a) equals: 42.
	! !

!GlobalIdentifierMergerTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 20:08'!
testMerge2
	"Existing has something. Stored has another key."
	existing at: #a put: 42.
	stored at: #b put: 21.
	self assert: merger merge.
	self deny: existing = stored.
	self assert: existing size equals: 2.
	self assert: stored size equals: 1.
	self assert: (existing at: #a) equals: 42.
	self assert: (existing at: #b) equals: 21.
	! !

!GlobalIdentifierMergerTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 20:08'!
testMerge3
	"Existing has same key as stored."
	existing at: #a put: 42.
	stored at: #a put: 21.
	self deny: merger merge.
	self deny: existing = stored.
	self assert: existing size equals: 1.
	self assert: stored size equals: 1.
	self assert: (existing at: #a) equals: 42.
	! !

!GlobalIdentifierMergerTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 20:08'!
testMerger4
	"Existing has different computer id as stored."
	existing at: #computerUUID put: 42.
	existing at: #a put: 43.
	existing at: #c put: 44.
	stored at: #computerUUID put: 21.
	stored at: #b put: 22.
	stored at: #c put: 23.
	self assert: merger merge.
	self deny: existing = stored.
	self assert: existing size equals: 4.
	self assert: stored size equals: 3.
	self assert: (existing at: #computerUUID) equals: 21.
	self assert: (existing at: #a) equals: 43.
	self assert: (existing at: #b) equals: 22.
	self assert: (existing at: #c) equals: 23.
! !

!GlobalIdentifierMergerTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 20:11'!
testMerger5
	"Existing has different computer id as stored."
	existing at: #computerUUID put: 42.
	existing at: #a put: 43.
	existing at: #c put: 44.
	stored at: #b put: 22.
	stored at: #c put: 23.
	self assert: merger merge.
	self deny: existing = stored.
	self assert: existing size equals: 4.
	self assert: stored size equals: 2.
	self assert: (existing at: #computerUUID) equals: 42.
	self assert: (existing at: #a) equals: 43.
	self assert: (existing at: #b) equals: 22.
	self assert: (existing at: #c) equals: 44.
! !

!GlobalIdentifierMergerTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 20:12'!
testMerger6
	"Existing has different computer id as stored."
	existing at: #a put: 43.
	existing at: #c put: 44.
	stored at: #computerUUID put: 21.
	stored at: #b put: 22.
	stored at: #c put: 23.
	self assert: merger merge.
	self deny: existing = stored.
	self assert: existing size equals: 4.
	self assert: stored size equals: 3.
	self assert: (existing at: #computerUUID) equals: 21.
	self assert: (existing at: #a) equals: 43.
	self assert: (existing at: #b) equals: 22.
	self assert: (existing at: #c) equals: 23.
! !

TestCase subclass: #GlobalIdentifierPersistenceTest
	instanceVariableNames: 'preferences persistence'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests'!

!GlobalIdentifierPersistenceTest commentStamp: '<historical>' prior: 0!
A GlobalIdentifierPersistenceTest is a test class for testing the behavior of GlobalIdentifierPersistence!

GlobalIdentifierPersistenceTest subclass: #GlobalIdentifierFuelPersistenceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests'!

!GlobalIdentifierFuelPersistenceTest commentStamp: '<historical>' prior: 0!
A GlobalIdentifierFuelPersistenceTest is a test class for testing the behavior of GlobalIdentifierFuelPersistence!

!GlobalIdentifierFuelPersistenceTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 17:05'!
folderName
	^ 'pharoPreferencesTestFolder'! !

!GlobalIdentifierFuelPersistenceTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 16:59'!
persistenceClass
	^ GlobalIdentifierFuelPersistence! !

!GlobalIdentifierFuelPersistenceTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 17:01'!
setUpPreferences
	preferences := FileLocator workingDirectory / self folderName / 'pharoX' / 'preferences.fuel'.
	preferences ensureDelete.! !

!GlobalIdentifierFuelPersistenceTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 17:02'!
tearDown
	(FileLocator workingDirectory / self folderName) 
		ensureDeleteAllChildren; 
		ensureDelete.! !

!GlobalIdentifierPersistenceTest class methodsFor: 'testing' stamp: 'JurajKubelka 10/10/2015 16:55'!
isAbstract
	^ self name = GlobalIdentifierPersistenceTest name! !

!GlobalIdentifierPersistenceTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 16:58'!
persistenceClass
	^ self subclassResponsibility! !

!GlobalIdentifierPersistenceTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 16:58'!
setUp
	super setUp.
	self setUpPreferences.
	persistence := self persistenceClass new preferences: preferences; yourself.! !

!GlobalIdentifierPersistenceTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 16:58'!
setUpPreferences
	self subclassResponsibility! !

!GlobalIdentifierPersistenceTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 17:02'!
tearDown
	super tearDown.
	preferences ensureDelete.
! !

!GlobalIdentifierPersistenceTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 17:05'!
testDefault
	self deny: preferences exists description: 'The preference file should not exists by default.'.
	self deny: preferences parent exists description: 'The preference directory should not exists by default.'! !

!GlobalIdentifierPersistenceTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 19:16'!
testDelete
	preferences parent ensureCreateDirectory.
	preferences ensureCreateFile.
	self assert: preferences exists.
	persistence delete.
	self deny: preferences exists.
	! !

!GlobalIdentifierPersistenceTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 19:16'!
testEnsureDirectory
	persistence ensureDirectory.
	self assert: preferences parent exists.
	self deny: preferences exists.
	! !

!GlobalIdentifierPersistenceTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 19:19'!
testLoad
	"Load when nothing is stored."
	| values |
	values := Dictionary new.
	values at: #a put: 42.
	persistence load: values.
	self assert: values size equals: 1.
	self assert: (values at: #a) equals: 42.
	self assert: preferences exists.! !

!GlobalIdentifierPersistenceTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 19:22'!
testLoad2
	"Load stored values."
	| values loaded |
	values := Dictionary new.
	values at: #a put: 42.
	persistence save: values.
	loaded := Dictionary new.
	persistence load: loaded.
	self assert: loaded equals: values.
! !

!GlobalIdentifierPersistenceTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 19:20'!
testSave
	| values |
	values := Dictionary new.
	values at: #a put: 42.
	persistence save: values.
	self assert: preferences exists.! !

TestCase subclass: #GlobalIdentifierTest
	instanceVariableNames: 'disk preferences identifier persistence'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests'!

!GlobalIdentifierTest commentStamp: '<historical>' prior: 0!
A GlobalIdentifierTest is a test class for testing the behavior of GlobalIdentifier!

!GlobalIdentifierTest methodsFor: 'accessing' stamp: 'JurajKubelka 10/10/2015 17:15'!
folderName
	^ 'pharoPreferencesTestFolder'! !

!GlobalIdentifierTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 18:45'!
setUp
	super setUp.
	"disk := FileSystem memory."
	preferences := FileLocator workingDirectory / self folderName / 'pharoX' / 'preferences.fuel'.
	preferences ensureDelete.
	persistence := GlobalIdentifierPersistence fuel.
	persistence preferences: preferences.
	identifier := GlobalIdentifier basicNew initialize persistenceStrategy: persistence; yourself.! !

!GlobalIdentifierTest methodsFor: 'running' stamp: 'JurajKubelka 10/10/2015 17:15'!
tearDown
	super tearDown.
	"disk := FileSystem memory."
	preferences ensureDelete.
	(FileLocator workingDirectory / self folderName) 
		ensureDeleteAllChildren; 
		ensureDelete.! !

!GlobalIdentifierTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 19:09'!
testComputerUUID
	"The computer UUID is not stored immediately because the Pharo Integration Server
	raised building errors when storing the computer UUID on the CI server."
	self assert: identifier computerUUID notNil.
	self assert: identifier computerUUID isString.
	self testDefault.! !

!GlobalIdentifierTest methodsFor: 'tests' stamp: 'JurajKubelka 9/1/2015 19:13'!
testDefault
	self deny: preferences exists description: 'The preference file should not exists by default.'.
	self deny: preferences parent exists description: 'The preference directory should not exists by default.'! !

!GlobalIdentifierTest methodsFor: 'tests' stamp: 'JurajKubelka 10/10/2015 20:46'!
testEnsure
	"The computer UUID is not stored immediately because the Pharo Integration Server
	raised building errors when storing the computer UUID on the CI server."
	| stored |
	identifier ensure.
	self assert: preferences exists description: 'The preferences should be stored now.'.
	stored := persistence load.
	self assert: stored equals: identifier persistedInformation.! !

Object subclass: #GTDummyEvent
	instanceVariableNames: 'data'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GT-EventRecorder-Tests'!

!GTDummyEvent methodsFor: 'comparing' stamp: 'JurajKubelka 10/9/2015 15:42'!
= aDummyEvent
	^ self class = aDummyEvent class and: [ 
		self data = aDummyEvent data ]! !

!GTDummyEvent methodsFor: 'accessing' stamp: 'JurajKubelka 10/9/2015 12:10'!
data
	^ data! !

!GTDummyEvent methodsFor: 'accessing' stamp: 'JurajKubelka 10/9/2015 12:10'!
data: anObject
	data := anObject! !

!GTDummyEvent methodsFor: 'comparing' stamp: 'JurajKubelka 10/9/2015 15:43'!
hash
	^ self class hash bitXor: self data! !
